function addEvent(elem, event, fn)
{
	if (elem.addEventListener)
	{
		elem.addEventListener(event, fn, false);
	}
	else
	{
		elem.attachEvent("on" + event, function()
		{
			// set the this pointer same as addEventListener when fn is called
			return (fn.call(elem, window.event));
		});
	}
}
var logs = [];
var eventSet = false;
var loaded = false;

function log(str)
{
	if (loaded)
	{
		output(str);
	}
	else
	{
		logs.push(str);
	}

	function output(str)
	{
		var o = document.getElementById("log");
		var div = document.createElement("div");
		div.appendChild(document.createTextNode(str));
		o.appendChild(div);
	}
	if (!eventSet)
	{
		eventSet = true;
		addEvent(window, "load", function()
		{
			loaded = true;
			for (var i = 0; i < logs.length; i++)
			{
				output(logs[i]);
			}
			logs = [];
		});
	}
}
(function(funcName, baseObj)
{
	// The public function name defaults to window.docReady
	// but you can pass in your own object and own function name and those will be used
	// if you want to put them in a different namespace
	funcName = funcName || "docReady";
	baseObj = baseObj || window;
	var readyList = [];
	var readyFired = false;
	var readyEventHandlersInstalled = false;
	// call this when the document is ready
	// this function protects itself against being called more than once
	function ready()
	{
		if (!readyFired)
		{
			// this must be set to true before we start calling callbacks
			readyFired = true;
			for (var i = 0; i < readyList.length; i++)
			{
				// if a callback here happens to add new ready handlers,
				// the docReady() function will see that it already fired
				// and will schedule the callback to run right after
				// this event loop finishes so all handlers will still execute
				// in order and no new ones will be added to the readyList
				// while we are processing the list
				readyList[i].fn.call(window, readyList[i].ctx);
			}
			// allow any closures held by these functions to free
			readyList = [];
		}
	}

	function readyStateChange()
	{
		if (document.readyState === "complete")
		{
			ready();
		}
	}
	// This is the one public interface
	// docReady(fn, context);
	// the context argument is optional - if present, it will be passed
	// as an argument to the callback
	baseObj[funcName] = function(callback, context)
	{
		// if ready has already fired, then just schedule the callback
		// to fire asynchronously, but right away
		if (readyFired)
		{
			setTimeout(function()
			{
				callback(context);
			}, 1);
			return;
		}
		else
		{
			// add the function and context to the list
			readyList.push(
			{
				fn: callback,
				ctx: context
			});
		}
		// if document already ready to go, schedule the ready function to run
		if (document.readyState === "complete")
		{
			setTimeout(ready, 1);
		}
		else if (!readyEventHandlersInstalled)
		{
			// otherwise if we don't have event handlers installed, install them
			if (document.addEventListener)
			{
				// first choice is DOMContentLoaded event
				document.addEventListener("DOMContentLoaded", ready, false);
				// backup is window load event
				window.addEventListener("load", ready, false);
			}
			else
			{
				// must be IE
				document.attachEvent("onreadystatechange", readyStateChange);
				window.attachEvent("onload", ready);
			}
			readyEventHandlersInstalled = true;
		}
	}
})("docReady", window);

window.cookies = (function()
{
	var forbidden_re, has_re, repl_re;
	repl_re = function(key)
	{
		return new RegExp("(?:^|.*;\\s*)" + escape(key).replace(/[\-\.\+\*]/g, "\\$&") + "\\s*\\=\\s*((?:[^;](?!;))*[^;]?).*");
	};
	has_re = function(key)
	{
		return new RegExp("(?:^|;\\s*)" + escape(key).replace(/[\-\.\+\*]/g, "\\$&") + "\\s*\\=");
	};
	forbidden_re = /^(?:expires|max\-age|path|domain|secure)$/;
	return {
		get: function(key)
		{
			if (!key || !this.has(key))
			{
				return null;
			}
			return unescape(document.cookie.replace(repl_re(key), "$1"));
		},
		set: function(key, value, end, path, domain, secure)
		{
			var expires;
			if (!key || forbidden_re.test(key))
			{
				return;
			}
			expires = "";
			if (end)
			{
				switch (typeof end)
				{
					case "number":
						expires = "; max-age=" + end;
						break;
					case "string":
						if (end === "unlimited")
						{
							expires = "; expires=" + "Fri, 10 Jul 2099 13:05:42 UTC";
						}
						else
						{
							expires = "; expires=" + end;
						}
						break;
					case "object":
						if (end.hasOwnProperty("toGMTString"))
						{
							expires = "; expires=" + end.toGMTString();
						}
				}
			}
			document.cookie = escape(key) + "=" + escape(value) + expires + (domain ? "; domain=" + domain : "") + (path ? "; path=" + path : "") + (secure ? "; secure" : "");
		},
		remove: function(key)
		{
			var expire_date;
			if (!key || !this.has(key))
			{
				return;
			}
			expire_date = new Date();
			expire_date.setDate(expire_date.getDate() - 100);
			document.cookie = escape(key) + "=; expires=" + expire_date.toGMTString() + "; path=/";
		},
		has: function(key)
		{
			return has_re(key).test(document.cookie);
		},
		object: function(key)
		{
			var item;
			if (!key || !this.has(key))
			{
				return;
			}
			item = this.get(key);
			return new Function("return " + unescape(item.replace(/\+/g, " ")))();
		}
	};
})();

var set_cookies = false; // true = включить, false = отключить
			
window.Marker = {
	default_marker: set_marker,
	get: function()
	{
		return cookies.get('marker');
	},
	set: function(value)
	{
		domain = window.location.hostname;
		expire = new Date(+(new Date) + 60 * 60 * 24 * 30 * 1e3);
		cookies.set('marker', value, expire.toGMTString(), '/', domain);
		return value;
	},
	handle_marker: function(value)
	{
		if (value && this._new_marker(value) && (this.is_affiliate(value) || !this.is_affiliate(this.get())))
		{
			return this.set(value);
		}
		if (!this.get())
		{
			return this.set(this.default_marker);
		}
		return this.get();
	},
	_new_marker: function(value)
	{
		return value !== this.get();
	},
	get_from_params: function()
	{
		var a, b, i, p;
		a = window.location.search.substr(1).split('&');
		if (a === "")
		{
			return {};
		}
		b = {};
		i = 0;
		while (i < a.length)
		{
			p = a[i].split("=", 2);
			if (p.length === 1)
			{
				b[p[0]] = "";
			}
			else
			{
				b[p[0]] = decodeURIComponent(p[1].replace(/\+/g, " "));
			}
			++i;
		}
		return b.marker;
	},
	get_marker: function()
	{
		if (this.get_from_params() != null)
		{
			this.set(this.get_from_params())
		}
		if (this.get() == null)
		{
			this.set(this.default_marker);
		}
		return this.get() || this.default_marker;
	}
};


if ( set_cookies == true ) {
    marker = Marker.get_marker();
} else {
    var get_marker = Marker.get_from_params();
    if ( get_marker == undefined ) {
        marker = set_marker;
    } else {
        marker = get_marker;
    }

};


function setSrc(script, el) {
	console.log(el);
	if ( $(window).width() >= 1023 ) {
		script.setAttribute('src', '//c26.travelpayouts.com/content?promo_id=1150&shmarker=' + marker +'&widget=890');
	}
	el.append(script);
}

docReady(function()
{
	var script1 = document.createElement('script');

	script1.setAttribute('charset', 'utf-8');
	script1.setAttribute('async', 'true');

	setSrc(script1, $('#searchForm__form'));

});

docReady(function()
{
	var href = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=http://level.travel";
	//var headBtns = $('.header__btn');
	var footBtn = $('.tours__list-link');
	//headBtns.attr('href', href);
	footBtn.attr('href', href);
	
	var leveltravelmainlink = $('.leveltravelmainlink');
	leveltravelmainlink.attr('href', href);
	
	var dest_Russia = $('.dest_Russia');
	var href_dest_Russia = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/russia";
	dest_Russia.attr('href', href_dest_Russia);
	
	var dest_Cypr = $('.dest_Cypr');
	var href_dest_Cypr = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/cyprus";
	dest_Cypr.attr('href', href_dest_Cypr);
	
	var dest_Thailand = $('.dest_Thailand');
	var href_dest_Thailand = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/thailand";
	dest_Thailand.attr('href', href_dest_Thailand);

	var dest_UAE = $('.dest_UAE');
	var href_dest_UAE = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/uae";
	dest_UAE.attr('href', href_dest_UAE);
	
	var dest_Mont = $('.dest_Mont');
	var href_dest_Mont = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/montenegro";
	dest_Mont.attr('href', href_dest_Mont);
	
	var dest_Israel = $('.dest_Israel');
	var href_dest_Israel = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/israel";
	dest_Israel.attr('href', href_dest_Israel);	

	var dest_Vietnam = $('.dest_Vietnam');
	var href_dest_Vietnam = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/vietnam";
	dest_Vietnam.attr('href', href_dest_Vietnam);		
	
	var dest_Italy = $('.dest_Italy');
	var href_dest_Italy = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/italy";
	dest_Italy.attr('href', href_dest_Italy);			
	
	var dest_France = $('.dest_France');
	var href_dest_France = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/france";
	dest_France.attr('href', href_dest_France);	
	
	var dest_Jord = $('.dest_Jord');
	var href_dest_Jord = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/jordan";
	dest_Jord.attr('href', href_dest_Jord);

	var dest_Horv = $('.dest_Horv');
	var href_dest_Horv = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/croatia";
	dest_Horv.attr('href', href_dest_Horv);
	
	var dest_Dominik = $('.dest_Dominik');
	var href_dest_Dominik = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/dominican_republic";
	dest_Dominik.attr('href', href_dest_Dominik);
	
	var dest_Bulgar = $('.dest_Bulgar');
	var href_dest_Bulgar = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/bulgaria";
	dest_Bulgar.attr('href', href_dest_Bulgar);
	
	var dest_Maroco = $('.dest_Maroco');
	var href_dest_Maroco = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/morocco";
	dest_Maroco.attr('href', href_dest_Maroco);
	
	var dest_Tunis = $('.dest_Tunis');
	var href_dest_Tunis = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/tunisia";
	dest_Tunis.attr('href', href_dest_Tunis);
	
	var dest_Greece = $('.dest_Greece');
	var href_dest_Greece = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/greece";
	dest_Greece.attr('href', href_dest_Greece);
	
	var dest_India = $('.dest_India');
	var href_dest_India = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/india";
	dest_India.attr('href', href_dest_India);
	
	var dest_Cuba = $('.dest_Cuba');
	var href_dest_Cuba = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/cuba";
	dest_Cuba.attr('href', href_dest_Cuba);
	
	var dest_Mexica = $('.dest_Mexica');
	var href_dest_Mexica = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/mexico";
	dest_Mexica.attr('href', href_dest_Mexica);
	
	var dest_Spain = $('.dest_Spain');
	var href_dest_Spain = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/spain";
	dest_Spain.attr('href', href_dest_Spain);
	
	var dest_CZ = $('.dest_CZ');
	var href_dest_CZ = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/czech_republic";
	dest_CZ.attr('href', href_dest_CZ);
	
	var dest_Malta = $('.dest_Malta');
	var href_dest_Malta = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/malta";
	dest_Malta.attr('href', href_dest_Malta);
	
	var dest_Turkey = $('.dest_Turkey');
	var href_dest_Turkey = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/countries/turkey";
	dest_Turkey.attr('href', href_dest_Turkey);
	
	var recommend__btn = $('.recommend__btn');
	var href_recommend__btn = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/testimonials";
	recommend__btn.attr('href', href_recommend__btn);

	var footer_link1 = $('.footer_link1');
	var footer_link1__href= "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=http://hot.level.travel/tours/calendar";
	footer_link1.attr('href', footer_link1__href);	
	
	var footer_link2 = $('.footer_link2');
	var footer_link2__href = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=http://hot.level.travel/";
	footer_link2.attr('href', footer_link2__href);

	var footer_link3 = $('.footer_link3');
	var footer_link3__href = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/kak-kupit-tur-online";
	footer_link3.attr('href', footer_link3__href);
	
	var footer_link4 = $('.footer_link4');
	var footer_link4__href = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=https://level.travel/faq";
	footer_link4.attr('href', footer_link4__href);
	
	var footer_link5 = $('.footer_link5');
	var footer_link5__href = "http://c26.travelpayouts.com/click?shmarker=" + marker + "&promo_id=660&source_type=customlink&type=click&custom_url=http://hot.level.travel/tours_lifehacks/";
	footer_link5.attr('href', footer_link5__href);
	
});

